============================================
Service Identity Verification for pyOpenSSL
============================================

Release v\ |release| (:doc:`What's new? <changelog>`).

.. include:: ../README.rst
   :start-after: begin

User's Guide
============

.. toctree::
   :maxdepth: 1

   installation
   implemented-standards
   api


Project Information
-------------------

.. toctree::
   :maxdepth: 1

   backward-compatibility
   license
   contributing
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
